# -*- coding: utf-8 -*-

from __future__ import absolute_import, unicode_literals

from django.conf.urls import include, patterns, url


urlpatterns = patterns(
    "",
    url(r"^menu/", include("djangocms_restapi.menu.urls"))
)



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

__title__ = "djangocms-restapi"
__version__ = "0.0.1"
__author__ = "Rolf Håvard Blindheim"
__license__ = "MIT License"

VERSION = __version__



# -*- coding: utf-8 -*-

from __future__ import absolute_import, unicode_literals

from datetime import datetime, timedelta
from cms.middleware.page import get_page


class CurrentPageCookieMiddleWare(object):
    """
    Sets the `current_page` in the Cookie Store.
    """

    def process_response(self, request, response):
        current_page = getattr(request, "current_page", get_page(request))
        if current_page:
            # Only update do this if we're on a "cms page"!
            current_page = current_page.get_absolute_url()

            if hasattr(request, "session"):
                session_page = request.session.get("current_page", None)
                if not session_page == current_page:
                    request.session["current_language"] = current_page
                    request.session.save()

            if "current_page" in request.COOKIES and request.COOKIES["current_page"] == current_page:
                return response

            max_age = 365 * 24 * 60 * 60  # 10 years
            expires = datetime.utcnow() + timedelta(seconds=max_age)
            response.set_cookie("current_page", current_page, expires=expires)
            return response

        return response



# -*- coding: utf-8 -*-

import os
import re

try:
    from setuptools import setup
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup


def get_version(package):
    """
    Return package version as listed in `__version__` in `init.py`.
    """
    init_py = open(os.path.join(package, "__init__.py")).read()
    return re.search("__version__ = ['\"]([^'\"]+)['\"]", init_py).group(1)

setup(
    name="djangocms-restapi",
    version=get_version("djangocms_restapi"),
    description="REST api interface for Django CMS",
    long_description="REST api interface for Django CMS based on Django REST Framework",
    author="Rolf Håvard Blindheim",
    author_email="rolf.blindheim@inonit.no",
    url="https://github.com/inonit/djangocms-restapi",
    download_url="https://github.com/inonit/djangocms-restapi.git",
    license="MIT License",
    packages=[
        "djangocms_restapi",
    ],
    include_package_data=True,
    install_requires=[
        "Django>=1.7.0",
        "djangorestframework>=3.1.0",
        "djangorestframework-recursive>=0.1.1",
        "django-cms>=3.1.0"
    ],
    tests_require=[
        "nose",
        "mock",
        "coverage",
    ],
    zip_safe=False,
    test_suite="tests.runtests.start",
    classifiers=[
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ]
)
